pyprocar.pyposcar.poscar_supercell — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.pyposcar.poscar_supercell

class pyprocar.pyposcar.poscar_supercell(poscar: Poscar | str, verbose: bool = False)

  class to generate a supercell by providing a supercell matrix.

  Methods

  `poscar_supercell.__init__`(poscar[, verbose]) | This class created a supercell of poscar, see the supercell method
  `poscar_supercell.supercell`(size) | Creates a supercell of the given size.
  `poscar_supercell.write`(filename[, ...]) | Just a convenience method to save the content into a file.